@extends('backpack::layout')

@section('header')
    <section class="content-header">
      <h1>
        {{ trans('backpack::logmanager.log_manager') }}<small>{{ trans('backpack::logmanager.log_manager_description') }}</small>
      </h1>
      <ol class="breadcrumb">
        <li><a href="{{ backpack_url('dashboard') }}">{{ trans('backpack::crud.admin') }}</a></li>
        <li><a href="{{ backpack_url('log') }}">{{ trans('backpack::logmanager.log_manager') }}</a></li>
        <li class="active">{{ trans('backpack::logmanager.existing_logs') }}</li>
      </ol>
    </section>
@endsection

@section('content')
<!-- Default box -->
  <div class="box">
    <div class="box-body">
      <table class="table table-hover table-condensed">
        <thead>
          <tr>
            <th>#</th>
            <th>{{ trans('backpack::logmanager.file_name') }}</th>
            <th>{{ trans('backpack::logmanager.date') }}</th>
            <th>{{ trans('backpack::logmanager.last_modified') }}</th>
            <th class="text-right">{{ trans('backpack::logmanager.file_size') }}</th>
            <th>{{ trans('backpack::logmanager.actions') }}</th>
          </tr>
        </thead>
        <tbody>
          @foreach ($files as $key => $file)
          <tr>
            <th scope="row">{{ $key + 1 }}</th>
            <td>{{ $file['file_name'] }}</td>
            <td>{{ \Carbon\Carbon::createFromTimeStamp($file['last_modified'])->formatLocalized('%d %B %Y') }}</td>
            <td>{{ \Carbon\Carbon::createFromTimeStamp($file['last_modified'])->formatLocalized('%H:%M') }}</td>
            <td class="text-right">{{ round((int)$file['file_size']/1048576, 2).' MB' }}</td>
            <td>
                <a class="btn btn-xs btn-default" href="{{ backpack_url('log/preview/'. encrypt($file['file_name'])) }}"><i class="fa fa-eye"></i> {{ trans('backpack::logmanager.preview') }}</a>
                <a class="btn btn-xs btn-default" href="{{ backpack_url('log/download/'.encrypt($file['file_name'])) }}"><i class="fa fa-cloud-download"></i> {{ trans('backpack::logmanager.download') }}</a>
                <a class="btn btn-xs btn-danger" data-button-type="delete" href="{{ backpack_url('log/delete/'.encrypt($file['file_name'])) }}"><i class="fa fa-trash-o"></i> {{ trans('backpack::logmanager.delete') }}</a>
            </td>
          </tr>
          @endforeach
        </tbody>
      </table>

    </div><!-- /.box-body -->
  </div><!-- /.box -->

@endsection

@section('after_scripts')
<script>
  jQuery(document).ready(function($) {

    // capture the delete button
    $("[data-button-type=delete]").click(function(e) {
        e.preventDefault();
        var delete_button = $(this);
        var delete_url = $(this).attr('href');

        if (confirm("{{ trans('backpack::logmanager.delete_confirm') }}") == true) {
            $.ajax({
                url: delete_url,
                type: 'DELETE',
                data: {
                  _token: "<?php echo csrf_token(); ?>"
                },
                success: function(result) {
                    // delete the row from the table
                    delete_button.parentsUntil('tr').parent().remove();

                    // Show an alert with the result
                    new PNotify({
                        title: "{{ trans('backpack::logmanager.delete_confirmation_title') }}",
                        text: "{{ trans('backpack::logmanager.delete_confirmation_message') }}",
                        type: "success"
                    });
                },
                error: function(result) {
                    // Show an alert with the result
                    new PNotify({
                        title: "{{ trans('backpack::logmanager.delete_error_title') }}",
                        text: "{{ trans('backpack::logmanager.delete_error_message') }}",
                        type: "warning"
                    });
                }
            });
        } else {
            new PNotify({
                title: "{{ trans('backpack::logmanager.delete_cancel_title') }}",
                text: "{{ trans('backpack::logmanager.delete_cancel_message') }}",
                type: "info"
            });
        }
      });

  });
</script>
@endsection
